@@ -8,12 +8,10 @@
 
 """invenio module that adds tugraz configs."""
 
-from flask_babelex import gettext as _
-
 from . import config
 
 
-class invenioconfigtugraz(object):
+class InvenioConfigTugraz(object):
     """invenio-config-tugraz extension."""
 
     def __init__(self, app=None):
@@ -24,10 +22,10 @@ class invenioconfigtugraz(object):
     def init_app(self, app):
         """Flask application initialization."""
         self.init_config(app)
-        app.extensions['invenio-config-tugraz'] = self
+        app.extensions["invenio-config-tugraz"] = self
 
     def init_config(self, app):
         """Initialize configuration."""
         for k in dir(config):
-            if k.startswith('INVENIO_CONFIG_TUGRAZ_'):
+            if k.startswith("INVENIO_CONFIG_TUGRAZ_"):
                 app.config.setdefault(k, getattr(config, k))
