@@ -7,11 +7,10 @@
 # modify it under the terms of the MIT License; see LICENSE file for more
 # details.
 
-docker-services-cli up postgresql es redis
-python -m check_manifest --ignore ".travis-*" && \
-python -m sphinx.cmd.build -qnNW docs docs/_build/html && \
-docker-services-cli up es postgresql redis
+python -m check_manifest --ignore ".*-requirements.txt"
+python -m sphinx.cmd.build -qnNW docs docs/_build/html
+docker-services-cli --verbose up es postgresql redis
 python -m pytest
 tests_exit_code=$?
 docker-services-cli down
-exit "$tests_exit_code" 
\ No newline at end of file
+exit "$tests_exit_code"
